#!perl -w
#
# admiral 
# 01/01/2002
#
# 

package CGI::Bus::lngbase::CGI_Bus_upws_ru; # Language base
use     CGI::Bus::lngbase::CGI_Bus_upws;
use strict;

1;

sub lngbase {
 my @msg =CGI::Bus::lngbase::CGI_Bus_upws::lngbase;
 push @msg,
 ('WorkSpace'   =>['WorkSpace', '']
 ,'Login'       =>['',     '  ']
 ,'Home'        =>['',    ' URL']
 ,'Overview'    =>['',     '  ']
 ,'Index'       =>['','   ']
 ,'USites'      =>['.',' ,         $_!']
 ,'USFHomes'    =>['.','     ']
 ,'USFHome'     =>['.','    ']
 ,'Setup'       =>['', '  ']
 ,'Logout'      =>['',     '  ,  ']
#,'Data Saved' 
#,'Data Loaded'
 ,'User'        =>['',   ' ']
 ,'Managed'     =>['',    ' ,  ']
 ,'Groups'      =>['',         ',    ,  ']
 ,'HomeURL'     =>[' URL',  'URL,  ;       \'\'    HTML ']
 ,'FramesetURLs'=>[' URL',   'URL \'\'  ,    ,  HTML \'\' ;      ']
 ,'FramesetRows'=>[' ',  '  ,   %,  ']
 ,'FramesetCols'=>[' ', '  ,   %,  ']
 ,'FavoriteURLs'=>[' URL',   'URL     ,    ,   \'|URL\', \'|_blank|URL\', \'|_parent|URL\', \'|URL|_|URL\',  HTML']
 ,'PrimaryRole' =>[' ',   '  ']
 ,'Read'        =>['',      ' ']
 ,'Save'        =>['',       ' ']
 ,'Refresh'     =>['',       '   ']
 );
 @msg
}

